## ######################################################################
##                              PROG_TIC
## ######################################################################
## Librería de utililerías para juegos 2D (funciona sobre pygame).
## Pensado para hacer juegos en la asignatura de TIC I en 1º de Bachillerato
## ######################################################################
##
## Clases que incluye:
##  Graficador: Sirve para crear gráficos en BMP a dos colores a partir de
##              un array de enteros (cada entero en binario representa una
##				línea de bits). Se puede añadir píxeles del color que se quiera.

##  Ventana: 	Clase que muestra una ventana con su título y ejecuta el método
## 				run de una clase que le ha de pasar al método. Es la base para 
##              crear juego, pues al redefinir el método run, Ventana ejecuta
##				este cada "frame" del juego. 

## Métodos: 
## cargaGrafico(fichero): dado un fichero en bmp, devuelve un objeto "grafico"
##                      propio de la librería pygame. Dicho gráfico se reescala
##                      al tamaño dado en la librería TAM_GRAF.

## Variables:
## TAM_GRAF: factor de escala de los gráficos.
## TAM_X: anchura en píxeles de la ventana. Por defecto 480.
## TAM_Y: altura en píxeles de la ventana. Por defecto 320.

## Define los colores: AZUL, ROJO, VERDE, AMARILLO, BLANCO, NEGRO, GRIS, GRIS_CLARO
## Inicializar la librería pygame.
## define una variable "pantalla" con el manejardor
## gráfico para imprimir en este los diferentes gráficos.
